<?php

/*
 * This file is part of Selenium Tor Driver.
 * (c) R. Eric Wheeler <eric@rewiv.com>
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace Sikofitt\WebDriver;

/**
 * Class ImageDownloader
 *
 * @package Sikofitt\WebDriver
 */
class ImageDownloader
{
    const CURLPROXY_SOCKS5_HOSTNAME = 7;

    private $fileInfo;
    private $curl;
    private $data;
    private $pathinfo;
    private $timeout;
    private $proxyUrl;
    private $file;

  /**
   * ImageDownloader constructor.
   *
   * @param int    $timeout
   * @param string $proxyUrl
   */
  public function __construct($timeout = 120, $proxyUrl = '127.0.0.1:9150')
  {
      $this->timeout = $timeout;
      $this->proxyUrl = $proxyUrl;
  }

  /**
   * @return string
   */
  public function getProxyUrl()
  {
      return $this->proxyUrl;
  }

  /**
   * @param $proxyUrl
   *
   * @return $this
   */
  public function setProxyUrl($proxyUrl)
  {
      $this->proxyUrl = $proxyUrl;
    // Reinitialize file;
    if (null !== $this->file) {
        $this->open($this->file);
    }
      return $this;
  }

  /**
   * @param $file
   */
  public function open($file)
  {
      $this->file = $file;
      $this->fileInfo = new \SplFileInfo($file);
      $this->curl = curl_init($file);
      curl_setopt_array($this->curl,
      array(
        CURLOPT_PROXY          => $this->proxyUrl,
        CURLOPT_PROXYTYPE      => self::CURLPROXY_SOCKS5_HOSTNAME,
        CURLOPT_HEADER         => 0,
        // Has to be 0, if set to 1 saves the header to the image file
        CURLOPT_TIMEOUT        => $this->timeout,
        // .onion urls often takes time to load
        CURLOPT_FOLLOWLOCATION => 1,
        CURLOPT_RETURNTRANSFER => 1,
      )
    );
      $this->pathinfo = parse_url($file);
      $this->data = curl_exec($this->curl);
  }

  /**
   * @return int
   */
  public function getTimeout()
  {
      return $this->timeout;
  }

  /**
   * @param $timeout
   *
   * @return $this
   */
  public function setTimeOut($timeout)
  {
      $this->timeout = $timeout;
    // Reinitialize file;
    if (null !== $this->file) {
        $this->open($this->file);
    }
      return $this;
  }

  /**
   * @return array
   *   Fileinfo array
   */
  public function getData()
  {
      return array(
      'filename' => $this->fileInfo->getFilename(),
      'data'     => $this->data,
      'pathinfo' => $this->pathinfo,
    );
  }

    public function getData64()
    {
        return array(
      'filename' => $this->fileInfo->getFilename(),
      'data'     => base64_encode($this->data),
      'pathinfo' => $this->pathinfo,
    );
    }

  /**
   * @return mixed
   */
  public function getPathInfo()
  {
      return $this->pathinfo;
  }

  /**
   * @param $file
   *
   * @return $this
   */
  public function setFile($file)
  {
      $this->fileInfo = new \SplFileInfo($file);

      return $this;
  }

  /**
   * @return mixed
   */
  public function getCurlInfo()
  {
      return curl_getinfo($this->curl);
  }

  /**
   * @param      $path
   *   The filepath to save to.
   * @param bool $base64
   *   If set to true will save as base64 encoded data.
   *
   * @return void
   */
  public function save($path, $base64 = false)
  {
      // Make sure we were not passed a filename.
    // If we were remove the filename.
    if (strlen(pathinfo($path, PATHINFO_EXTENSION)) > 0) {
        $path = pathinfo($path, PATHINFO_DIRNAME);
    }
    // Make sure path exists.
    if (!is_dir($path)) {
        mkdir($path, 0775, true);
    }
    // trim leading / if it exists.
    $path = rtrim($path, '/');

      if (true === $base64) {
          $fileContent = base64_encode($this->data);
      } else {
          $fileContent = $this->data;
      }

      file_put_contents($path . '/' . $this->getFileName() . (true === $base64 ? '.b64.txt' : ''),
      $fileContent);
  }

  /**
   * @return mixed
   */
  public function getFileName()
  {
      return $this->fileInfo->getFileName();
  }

  /**
   * Close the curl handle.
   */
  public function __destruct()
  {
      curl_close($this->curl);
  }
}
